==> jc-1.4.0.tar.gz: java/awt/image/renderable/RenderableImageProducer.h <==
// public class java.awt.image.renderable.RenderableImageProducer

// class file dependencies
// @dep_class b0117585236ad156 java_awt_image_renderable_RenderableImageProducer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_image_renderable_RenderableImageProducer_H_
#define _JC_java_awt_image_renderable_RenderableImageProducer_H_

// Forward structure declarations
struct _jc_java_awt_image_ImageConsumer$object;
struct _jc_java_awt_image_renderable_RenderContext$object;
struct _jc_java_awt_image_renderable_RenderableImage$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_renderable_RenderableImageProducer$sub_refs	_jc_java_awt_image_renderable_RenderableImageProducer$sub_refs;
typedef struct _jc_java_awt_image_renderable_RenderableImageProducer$sub_nonrefs	_jc_java_awt_image_renderable_RenderableImageProducer$sub_nonrefs;
typedef struct _jc_java_awt_image_renderable_RenderableImageProducer$refs	_jc_java_awt_image_renderable_RenderableImageProducer$refs;
typedef struct _jc_java_awt_image_renderable_RenderableImageProducer$nonrefs	_jc_java_awt_image_renderable_RenderableImageProducer$nonrefs;
typedef struct _jc_java_awt_image_renderable_RenderableImageProducer$object	_jc_java_awt_image_renderable_RenderableImageProducer$object;

typedef const struct _jc_java_awt_image_renderable_RenderableImageProducer$vmethods	_jc_java_awt_image_renderable_RenderableImageProducer$vmethods;
typedef const struct _jc_java_awt_image_renderable_RenderableImageProducer$vtable	_jc_java_awt_image_renderable_RenderableImageProducer$vtable;
typedef const struct _jc_java_awt_image_renderable_RenderableImageProducer$vtype	_jc_java_awt_image_renderable_RenderableImageProducer$vtype;

// Constructors
extern void _jc_java_awt_image_renderable_RenderableImageProducer$method$_init$354a3bd3beccc67e(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *, struct _jc_java_awt_image_renderable_RenderContext$object *);

// Virtual methods
extern void _jc_java_awt_image_renderable_RenderableImageProducer$method$addConsumer$280f4229ae568632(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *);
extern jboolean _jc_java_awt_image_renderable_RenderableImageProducer$method$isConsumer$2e7ee3184ebf4388(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *);
extern void _jc_java_awt_image_renderable_RenderableImageProducer$method$removeConsumer$c1effed99882a87d(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *);
extern void _jc_java_awt_image_renderable_RenderableImageProducer$method$requestTopDownLeftRightResend$9c3b642896e809d4(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *);
extern void _jc_java_awt_image_renderable_RenderableImageProducer$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *);
extern void _jc_java_awt_image_renderable_RenderableImageProducer$method$setRenderContext$5bb8b4617b365191(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_java_awt_image_renderable_RenderContext$object *);
extern void _jc_java_awt_image_renderable_RenderableImageProducer$method$startProduction$34c5bb40595e132a(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_renderable_RenderableImageProducer$method_info$addConsumer$280f4229ae568632;
extern _jc_method _jc_java_awt_image_renderable_RenderableImageProducer$method_info$isConsumer$2e7ee3184ebf4388;
extern _jc_method _jc_java_awt_image_renderable_RenderableImageProducer$method_info$removeConsumer$c1effed99882a87d;
extern _jc_method _jc_java_awt_image_renderable_RenderableImageProducer$method_info$requestTopDownLeftRightResend$9c3b642896e809d4;
extern _jc_method _jc_java_awt_image_renderable_RenderableImageProducer$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_java_awt_image_renderable_RenderableImageProducer$method_info$setRenderContext$5bb8b4617b365191;
extern _jc_method _jc_java_awt_image_renderable_RenderableImageProducer$method_info$startProduction$34c5bb40595e132a;

// Virtual methods structure
struct _jc_java_awt_image_renderable_RenderableImageProducer$vmethods {
	void	(*addConsumer$280f4229ae568632)(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *);
	jboolean	(*isConsumer$2e7ee3184ebf4388)(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *);
	void	(*removeConsumer$c1effed99882a87d)(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *);
	void	(*requestTopDownLeftRightResend$9c3b642896e809d4)(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *);
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *);
	void	(*setRenderContext$5bb8b4617b365191)(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_java_awt_image_renderable_RenderContext$object *);
	void	(*startProduction$34c5bb40595e132a)(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *);
};

// Vtable
struct _jc_java_awt_image_renderable_RenderableImageProducer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_renderable_RenderableImageProducer$vmethods	java_awt_image_renderable_RenderableImageProducer;
};

// Vtype
struct _jc_java_awt_image_renderable_RenderableImageProducer$vtype {
	_jc_type			type;
	_jc_java_awt_image_renderable_RenderableImageProducer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_renderable_RenderableImageProducer$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_image_renderable_RenderableImageProducer$refs {
    _jc_java_awt_image_renderable_RenderableImageProducer$sub_refs	java_awt_image_renderable_RenderableImageProducer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_renderable_RenderableImageProducer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_renderable_RenderableImageProducer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_renderable_RenderableImageProducer$sub_nonrefs	java_awt_image_renderable_RenderableImageProducer;
};

// Object instance structure
struct _jc_java_awt_image_renderable_RenderableImageProducer$object {
	_jc_java_awt_image_renderable_RenderableImageProducer$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_renderable_RenderableImageProducer$vtype	*vtype;
	_jc_java_awt_image_renderable_RenderableImageProducer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_renderable_RenderableImageProducer$vtype _jc_java_awt_image_renderable_RenderableImageProducer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_renderable_RenderableImageProducer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_renderable_RenderableImageProducer$class_object;

#endif	/* _JC_java_awt_image_renderable_RenderableImageProducer_H_ */

==> jc-1.4.6.tar.gz: java/awt/image/renderable/RenderableImageProducer.h <==
// public class java.awt.image.renderable.RenderableImageProducer

// class file dependencies
// @dep_class b0117585236ad156 java_awt_image_renderable_RenderableImageProducer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_image_renderable_RenderableImageProducer_H_
#define _JC_java_awt_image_renderable_RenderableImageProducer_H_

// Forward structure declarations
struct _jc_java_awt_image_ImageConsumer$object;
struct _jc_java_awt_image_renderable_RenderContext$object;
struct _jc_java_awt_image_renderable_RenderableImage$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_image_renderable_RenderableImageProducer$sub_refs	_jc_java_awt_image_renderable_RenderableImageProducer$sub_refs;
typedef struct _jc_java_awt_image_renderable_RenderableImageProducer$sub_nonrefs	_jc_java_awt_image_renderable_RenderableImageProducer$sub_nonrefs;
typedef struct _jc_java_awt_image_renderable_RenderableImageProducer$refs	_jc_java_awt_image_renderable_RenderableImageProducer$refs;
typedef struct _jc_java_awt_image_renderable_RenderableImageProducer$nonrefs	_jc_java_awt_image_renderable_RenderableImageProducer$nonrefs;
typedef struct _jc_java_awt_image_renderable_RenderableImageProducer$object	_jc_java_awt_image_renderable_RenderableImageProducer$object;

typedef const struct _jc_java_awt_image_renderable_RenderableImageProducer$vmethods	_jc_java_awt_image_renderable_RenderableImageProducer$vmethods;
typedef const struct _jc_java_awt_image_renderable_RenderableImageProducer$vtable	_jc_java_awt_image_renderable_RenderableImageProducer$vtable;
typedef const struct _jc_java_awt_image_renderable_RenderableImageProducer$vtype	_jc_java_awt_image_renderable_RenderableImageProducer$vtype;

// Constructors
extern void _jc_java_awt_image_renderable_RenderableImageProducer$method$_init$354a3bd3beccc67e(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *, struct _jc_java_awt_image_renderable_RenderContext$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_image_renderable_RenderableImageProducer$method$addConsumer$280f4229ae568632(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_image_renderable_RenderableImageProducer$method$isConsumer$2e7ee3184ebf4388(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_renderable_RenderableImageProducer$method$removeConsumer$c1effed99882a87d(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_renderable_RenderableImageProducer$method$requestTopDownLeftRightResend$9c3b642896e809d4(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_renderable_RenderableImageProducer$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_renderable_RenderableImageProducer$method$setRenderContext$5bb8b4617b365191(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_java_awt_image_renderable_RenderContext$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_renderable_RenderableImageProducer$method$startProduction$34c5bb40595e132a(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_renderable_RenderableImageProducer$method_info$addConsumer$280f4229ae568632;
extern _jc_method _jc_java_awt_image_renderable_RenderableImageProducer$method_info$isConsumer$2e7ee3184ebf4388;
extern _jc_method _jc_java_awt_image_renderable_RenderableImageProducer$method_info$removeConsumer$c1effed99882a87d;
extern _jc_method _jc_java_awt_image_renderable_RenderableImageProducer$method_info$requestTopDownLeftRightResend$9c3b642896e809d4;
extern _jc_method _jc_java_awt_image_renderable_RenderableImageProducer$method_info$run$8b940e4957c86ebf;
extern _jc_method _jc_java_awt_image_renderable_RenderableImageProducer$method_info$setRenderContext$5bb8b4617b365191;
extern _jc_method _jc_java_awt_image_renderable_RenderableImageProducer$method_info$startProduction$34c5bb40595e132a;

// Virtual methods structure
struct _jc_java_awt_image_renderable_RenderableImageProducer$vmethods {
	void	(*addConsumer$280f4229ae568632)(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*isConsumer$2e7ee3184ebf4388)(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*removeConsumer$c1effed99882a87d)(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*requestTopDownLeftRightResend$9c3b642896e809d4)(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *) _JC_JCNI_ATTR;
	void	(*setRenderContext$5bb8b4617b365191)(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_java_awt_image_renderable_RenderContext$object *) _JC_JCNI_ATTR;
	void	(*startProduction$34c5bb40595e132a)(_jc_env *, struct _jc_java_awt_image_renderable_RenderableImageProducer$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_image_renderable_RenderableImageProducer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_renderable_RenderableImageProducer$vmethods	java_awt_image_renderable_RenderableImageProducer;
};

// Vtype
struct _jc_java_awt_image_renderable_RenderableImageProducer$vtype {
	_jc_type			type;
	_jc_java_awt_image_renderable_RenderableImageProducer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_renderable_RenderableImageProducer$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_image_renderable_RenderableImageProducer$refs {
    _jc_java_awt_image_renderable_RenderableImageProducer$sub_refs	java_awt_image_renderable_RenderableImageProducer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_renderable_RenderableImageProducer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_renderable_RenderableImageProducer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_renderable_RenderableImageProducer$sub_nonrefs	java_awt_image_renderable_RenderableImageProducer;
};

// Object instance structure
struct _jc_java_awt_image_renderable_RenderableImageProducer$object {
	_jc_java_awt_image_renderable_RenderableImageProducer$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_renderable_RenderableImageProducer$vtype	*vtype;
	_jc_java_awt_image_renderable_RenderableImageProducer$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_renderable_RenderableImageProducer$vtype _jc_java_awt_image_renderable_RenderableImageProducer$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_renderable_RenderableImageProducer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_renderable_RenderableImageProducer$class_object;

#endif	/* _JC_java_awt_image_renderable_RenderableImageProducer_H_ */
